Module net

Module net 

TCP and Unix domain socket listener implementations.

This module provides async listener abstractions for TCP and Unix domain sockets.

Additionally, we provides:

Structs

TcpListener
A TCP socket listener that implements AsyncListener.
TcpStream
A TCP stream that implements AsyncRead and AsyncWrite.
UnixListener
A Unix domain socket listener that implements AsyncListener.
UnixStream
A Unix stream that implements AsyncRead and AsyncWrite.

Enums

UnifyAddr
Unify behavior of tcp & unix addr
UnifyListener
Unify behavior of tcp & unix socket listener, provides ad bind that directly accept str
UnifyStream
Unify behavior of tcp & unix stream

Traits

AsyncListener
Trait for async listener operations.
ResolveAddr
Resolve addr in async to one address for listen or connect