UnifyStream

Enum UnifyStream 

pub enum UnifyStream<IO: AsyncIO> {
    Tcp(TcpStream<IO>),
    Unix(UnixStream<IO>),
}
Unify behavior of tcp & unix stream

Variants



Tcp(TcpStream<IO>)



Unix(UnixStream<IO>)

Implementations

Source

impl<IO: AsyncIO> UnifyStream<IO>

pub async fn connect<A: ResolveAddr + ?Sized>(addr: &A) -> Result<Self>
where IO: AsyncRuntime,

Connect to a unified address asynchronously.

This method attempts to establish a connection to the specified address, automatically determining whether to use TCP or Unix socket based on the address type.

Parameters
  • addr - The address to connect to, can be a string, SocketAddr, or PathBuf
Returns

A future that resolves to a Result containing either the connected UnifyStream or an I/O error.

pub async fn connect_timeout<A>(addr: &A, timeout: Duration) -> Result<Self>
where IO: AsyncRuntime, A: ResolveAddr + ?Sized,

Connect to a unified address asynchronously with a timeout.

This method attempts to establish a connection to the specified address, automatically determining whether to use TCP or Unix socket based on the address type. If the connection attempt takes longer than the specified timeout, an error will be returned.

Parameters
  • addr - The address to connect to, can be a string, SocketAddr, or PathBuf
  • timeout - The maximum time to wait for the connection
Returns

A future that resolves to a Result containing either the connected UnifyStream or an I/O error.

pub async fn shutdown_write(&mut self) -> Result<()>

pub fn peer_addr(&self) -> Result<SocketAddr>